@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from enum import Enum
 from typing import List, Optional
 
 from pydantic import BaseModel
@@ -19,6 +20,33 @@ class AddressInfoResult(BaseModel):
     data: Optional[str] = None
 
 
+class BroadcastStatusEnum(str, Enum):
+    broadcasted = "broadcasted"
+    commited = "commited"
+    failed = "failed"
+
+
+class BroadcastResult(BaseModel):
+    waited: bool
+    status: BroadcastStatusEnum
+
+    class Config:
+        use_enum_values = True
+        validate_assignment = True
+
+    def __str__(self):
+        if self.status == BroadcastStatusEnum.commited:
+            return "Transaction has been commited."
+
+        if self.status == BroadcastStatusEnum.broadcasted:
+            if self.waited:
+                return "Transaction has been sent but hasn't been committed into blockchain during 30 seconds."
+            else:
+                return "Transaction has been sent."
+
+        return "Transaction hasn't been sent."
+
+
 class TonClient(ABC):
     @abstractmethod
     def __init__(self, config: Config):
@@ -35,14 +63,14 @@ class TonClient(ABC):
         raise NotImplementedError
 
     @abstractmethod
-    def seqno(self, addr: str):
+    def seqno(self, addr: str) -> int:
         raise NotImplementedError
 
     @abstractmethod
-    def deploy_wallet(self, wallet: WalletContract, wait_for_result=False):
+    def deploy_wallet(self, wallet: WalletContract, wait_for_result=False) -> BroadcastResult:
         raise NotImplementedError
 
     @abstractmethod
     def transfer(self, from_wallet: WalletContract, to_addr: str, amount: TonCurrencyEnum.ton, payload=None,
-                 send_mode=SendModeEnum.ignore_errors | SendModeEnum.pay_gas_separately, wait_for_result=False) -> bool:
+                 send_mode=SendModeEnum.ignore_errors | SendModeEnum.pay_gas_separately, wait_for_result=False) -> BroadcastResult:
         raise NotImplementedError
