@@ -74,7 +74,7 @@ class DAppTonClient(TonClient):
         timeout = 30 if wait_for_result else 0
         seqno = self.seqno(from_wallet.address.to_string())
         query = from_wallet.create_transfer_message(
-            to_addr=Address(to_addr).to_string(False, False, False),
+            to_addr=Address(to_addr).to_string(False, False, True),  # TODO: set is bounceable or not
             amount=to_nano(amount, TonCurrencyEnum.ton),
             seqno=seqno,
             payload=payload,
